==> babel-preset-medusa-package-1.1.14.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [1.1.14](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.13...babel-preset-medusa-package@1.1.14) (2021-09-14)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.13](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.12...babel-preset-medusa-package@1.1.13) (2021-07-26)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.12](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.10...babel-preset-medusa-package@1.1.12) (2021-07-15)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.11](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.10...babel-preset-medusa-package@1.1.11) (2021-07-15)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.10](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.9...babel-preset-medusa-package@1.1.10) (2021-07-02)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.9](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.8...babel-preset-medusa-package@1.1.9) (2021-06-22)


### Bug Fixes

* release assist ([668e8a7](https://github.com/medusajs/medusa/commit/668e8a740200847fc2a41c91d2979097f1392532))





## [1.1.8](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.7...babel-preset-medusa-package@1.1.8) (2021-06-09)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.7](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.6...babel-preset-medusa-package@1.1.7) (2021-06-09)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.6](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.5...babel-preset-medusa-package@1.1.6) (2021-06-09)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.5](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.4...babel-preset-medusa-package@1.1.5) (2021-06-09)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.4](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.3...babel-preset-medusa-package@1.1.4) (2021-06-08)


### Bug Fixes

* add optional chaining ([577da11](https://github.com/medusajs/medusa/commit/577da11b9809ce92accd4c623d86bc4967cc1f89))
* babel ([81960d5](https://github.com/medusajs/medusa/commit/81960d51812f093e04271f50ffe5de9bce17c06b))
* babel warning ([7fdca85](https://github.com/medusajs/medusa/commit/7fdca85bae1e0df653e707fc1b8c26652c02c5fe))





## [1.1.3](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.0...babel-preset-medusa-package@1.1.3) (2021-04-28)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.2](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.1...babel-preset-medusa-package@1.1.2) (2021-04-20)

**Note:** Version bump only for package babel-preset-medusa-package





## [1.1.1](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.0...babel-preset-medusa-package@1.1.1) (2021-04-20)

**Note:** Version bump only for package babel-preset-medusa-package





# [1.1.0](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.0.1...babel-preset-medusa-package@1.1.0) (2021-01-26)

**Note:** Version bump only for package babel-preset-medusa-package





## 1.0.1 (2020-11-24)

**Note:** Version bump only for package babel-preset-medusa-package

==> babel-preset-medusa-package-1.1.17.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [1.1.17](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.15...babel-preset-medusa-package@1.1.17) (2021-10-18)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.16](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.15...babel-preset-medusa-package@1.1.16) (2021-10-18)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.15](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.14...babel-preset-medusa-package@1.1.15) (2021-09-15)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.14](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.13...babel-preset-medusa-package@1.1.14) (2021-09-14)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.13](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.12...babel-preset-medusa-package@1.1.13) (2021-07-26)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.12](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.10...babel-preset-medusa-package@1.1.12) (2021-07-15)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.11](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.10...babel-preset-medusa-package@1.1.11) (2021-07-15)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.10](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.9...babel-preset-medusa-package@1.1.10) (2021-07-02)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.9](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.8...babel-preset-medusa-package@1.1.9) (2021-06-22)

### Bug Fixes

- release assist ([668e8a7](https://github.com/medusajs/medusa/commit/668e8a740200847fc2a41c91d2979097f1392532))

## [1.1.8](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.7...babel-preset-medusa-package@1.1.8) (2021-06-09)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.7](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.6...babel-preset-medusa-package@1.1.7) (2021-06-09)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.6](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.5...babel-preset-medusa-package@1.1.6) (2021-06-09)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.5](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.4...babel-preset-medusa-package@1.1.5) (2021-06-09)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.4](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.3...babel-preset-medusa-package@1.1.4) (2021-06-08)

### Bug Fixes

- add optional chaining ([577da11](https://github.com/medusajs/medusa/commit/577da11b9809ce92accd4c623d86bc4967cc1f89))
- babel ([81960d5](https://github.com/medusajs/medusa/commit/81960d51812f093e04271f50ffe5de9bce17c06b))
- babel warning ([7fdca85](https://github.com/medusajs/medusa/commit/7fdca85bae1e0df653e707fc1b8c26652c02c5fe))

## [1.1.3](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.0...babel-preset-medusa-package@1.1.3) (2021-04-28)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.2](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.1...babel-preset-medusa-package@1.1.2) (2021-04-20)

**Note:** Version bump only for package babel-preset-medusa-package

## [1.1.1](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.1.0...babel-preset-medusa-package@1.1.1) (2021-04-20)

**Note:** Version bump only for package babel-preset-medusa-package

# [1.1.0](https://github.com/medusajs/medusa/compare/babel-preset-medusa-package@1.0.1...babel-preset-medusa-package@1.1.0) (2021-01-26)

**Note:** Version bump only for package babel-preset-medusa-package

## 1.0.1 (2020-11-24)

**Note:** Version bump only for package babel-preset-medusa-package
